<?php
namespace HCM\AVL\Repository;

use Doctrine\DBAL\Connection;
use Doctrine\ORM\EntityManager;
use HCM\Util\Repositories;

class AvaliacaoRepository {

    public function __construct(Connection $connection, EntityManager $entityManager) {
        $this->connection = $connection;
        $this->entityManager = $entityManager;
        $this->questao = Repositories::QUESTAO;
        $this->questAvaliacao = Repositories::QUESTAVALIACAO;
        $this->agrupamento = Repositories::AGRUPQUESTAVAL;
        $this->combinacao = Repositories::COMBQUESTAVAL;
        $this->participantes = Repositories::PARTICIPAVAL;
        $this->questpadraval = Repositories::QUESTPADRAVAL;
        $this->agrupquestpadr = Repositories::AGRUPQUESTPADR;
        $this->combquestpadr = Repositories::COMBQUESTPADR;
        $this->tiporelacpadr = Repositories::TIPORELACPADR;
    }
    
    public function getQuestoes($comb,$agrup,$nivel,$tema,$ordem,$nrorg,$avaliacao){
        $where = "AND r.nravaliacao = ".$avaliacao;
        if(!is_null($comb)){
            $where .= " AND r.nrcombquestaval = ".$comb;
        }
        if(!is_null($agrup)){
            $where .= " AND r.nragrupquestava = ".$agrup;
        }
        if(!is_null($nivel)){
            $where .= " AND r.nrnivelquestao = ".$nivel;
        }
        if(!is_null($tema)){
            $where .= " AND r.nrtemaanalise = ".$tema;
        }
        if(!is_null($ordem)){
            $where .= " AND r.nrordequestaval = ".$ordem;
        }
        $sql = <<<SQL
            SELECT r.nrquestao
            FROM $this->questAvaliacao r
            WHERE r.nrorg = :P_NRORG
            $where
SQL;
        $params = array(
            'P_NRORG' => $nrorg
        );

        $resultado = $this->entityManager->createQuery($sql)->execute($params);

        return $resultado;
    }
    
    public function getQuestaoSorteio($nrorg,$nivel,$idSorteio){
        
        $where = '';
        if($nivel !== '' && $nivel !== NULL){
            $where .= ' AND r.nrnivelpadquest = '.$nivel;
        }
        if($idSorteio == 'FECHADA'){
            $where .= " AND r.idtipoquestao = 'FECHADA'";
        }else{
            $where .= " AND (r.idtipoquestao = 'ABERTA_TEXTO' OR r.idtipoquestao = 'ABERTA_VALOR' OR r.idtipoquestao = 'ABERTA_DATA')";
        }
        
        $sql = <<<SQL
            SELECT r.nrquestao
            FROM $this->questao r
            WHERE r.nrorg = :P_NRORG
            $where
SQL;
        $params = array(
            'P_NRORG' => $nrorg
        );
        $resultado = $this->entityManager->createQuery($sql)->execute($params);
        $resultado_rand = array_rand($resultado);
        return @$resultado[$resultado_rand]['nrquestao'];
    
    }
    
    public function questaoExists($nrorg,$avaliacao){
        $sql = <<<SQL
            SELECT r.nrquestao
            FROM $this->questAvaliacao r
            WHERE r.nrorg = :P_NRORG
            AND r.nravaliacao = :P_AVALIACAO
SQL;
        $params = array(
            'P_NRORG' => $nrorg,
            'P_AVALIACAO' => $avaliacao
        );
        $resultado = $this->entityManager->createQuery($sql)->execute($params);

        return !empty($resultado);
    }
    
    public function agrupExists($nrorg,$avaliacao){
        $sql = <<<SQL
            SELECT r.nragrupquestava
            FROM $this->agrupamento r
            WHERE r.nrorg = :P_NRORG
            AND r.nravaliacao = :P_AVALIACAO
SQL;
        $params = array(
            'P_NRORG' => $nrorg,
            'P_AVALIACAO' => $avaliacao
        );
        
        $resultado = $this->entityManager->createQuery($sql)->execute($params);
        
        return !empty($resultado);
    
    }
    
    public function combExists($nrorg,$avaliacao){
        
        $sql = <<<SQL
            SELECT r.nrcombquestaval
            FROM $this->combinacao r
            WHERE r.nrorg = :P_NRORG
            AND r.nravaliacao = :P_AVALIACAO
SQL;
        $params = array(
            'P_NRORG' => $nrorg,
            'P_AVALIACAO' => $avaliacao
        );

        $resultado = $this->entityManager->createQuery($sql)->execute($params);

        return !empty($resultado);
    
    }
    
    public function combPadraoExists($nrorg){
        
        $sql = <<<SQL
            SELECT r.nrcombquestaval
            FROM $this->combinacao r
            WHERE r.nrorg = :P_NRORG
            AND r.nravaliacao IS NULL
SQL;
        $params = array(
            'P_NRORG' => $nrorg
        );

        $resultado = $this->entityManager->createQuery($sql)->execute($params);
        return !empty($resultado);
    
    }
    
    public function relacExists($nrorg,$avaliacao){
        
        $sql = $this->entityManager->getConnection()->prepare(
            "SELECT r.NRTIPORELACAVAL
            FROM TIPORELACAVAL r
            WHERE r.NRORG = :P_NRORG
            AND r.nravaliacao = :P_AVALIACAO");
        $sql->execute(
            array(
                'P_NRORG' => $nrorg,
                'P_AVALIACAO' => $avaliacao
            )
        );
        
        return !empty($sql->fetchAll());
    }
    
    public function participanteExists($nrorg,$avaliacao){
        
        $sql = <<<SQL
            SELECT r.nrparticipaval
            FROM $this->participantes r
            WHERE r.nrorg = :P_NRORG
            AND r.nravaliacao = :P_AVALIACAO
SQL;
        $params = array(
            'P_NRORG' => $nrorg,
            'P_AVALIACAO' => $avaliacao
        );

        $resultado = $this->entityManager->createQuery($sql)->execute($params);

        return !empty($resultado);
    
    }
    
    public function getQuestPadrAval($nrorg,$questionario){
                
        $sql = $this->entityManager->getConnection()->prepare(
            "SELECT r.*
            FROM QUESTPADRAVAL r
            WHERE r.nrorg = :P_NRORG
            AND r.NRPADRAVALIACAO = :P_NRPADRAVAL"
        );
        $sql->execute(        
            array(
            'P_NRORG' => $nrorg,
            'P_NRPADRAVAL'=> $questionario
            )
        );
        return $sql->fetchAll();    
    }    
    
    public function getAgrupQuestPadr($nrorg,$questionario){
        $sql = $this->entityManager->getConnection()->prepare(
            "SELECT r.*
            FROM AGRUPQUESTPADR r
            WHERE r.nrorg = :P_NRORG
            AND r.NRPADRAVALIACAO = :P_NRPADRAVAL"
            
        );
        $sql->execute(
            array(
                'P_NRORG' => $nrorg,
                'P_NRPADRAVAL'=> $questionario   
            )
        );
        return $sql->fetchAll();        
    }
    
    public function getCombQuestPadr($nrorg,$questionario){
            $sql = $this->entityManager->getConnection()->prepare(
            "SELECT r.*
            FROM COMBQUESTPADR r
            WHERE r.nrorg = :P_NRORG
            AND r.NRPADRAVALIACAO = :P_NRPADRAVAL"
            );
        $sql->execute(        
            array(
            'P_NRORG' => $nrorg,
            'P_NRPADRAVAL'=> $questionario
            )
        );
        return $sql->fetchAll();        
    }

    public function getTipoRelacPadr($nrorg,$questionario){
            $sql = $this->entityManager->getConnection()->prepare(
            "SELECT r.*
            FROM TIPORELACPADR r
            WHERE r.nrorg = :P_NRORG
            AND r.NRPADRAVALIACAO = :P_NRPADRAVAL"
            );
        $sql->execute(        
            array(
            'P_NRORG' => $nrorg,
            'P_NRPADRAVAL'=> $questionario
            )
        );
        return $sql->fetchAll();         
    }

    public function validaTipoRelac($nrorg,$avaliacao,$nrtiporelacaval,$nrtiporelaciona){
        
        $sql = $this->entityManager->getConnection()->prepare(
            "SELECT r.NRTIPORELACAVAL
            FROM TIPORELACAVAL r
            WHERE r.NRORG = :P_NRORG
            AND r.nravaliacao = :P_AVALIACAO
            AND r.nrtiporelacaval != :P_NRTIPORELACAVAL
            AND r.nrtiporelaciona = :P_NRTIPORELACIONA
            
            ");
        $sql->execute(
            array(
                'P_NRORG' => $nrorg,
                'P_AVALIACAO' => $avaliacao,
                ":P_NRTIPORELACAVAL" => $nrtiporelacaval,
                ":P_NRTIPORELACIONA" => $nrtiporelaciona
            )
        );
        
        return empty($sql->fetchAll());
    }
    
    public function getCombinacao($nrorg, $nravaliacao){
        $sql = $this->entityManager->getConnection()->prepare(
            "SELECT r.*
            FROM COMBQUESTAVAL r
            WHERE r.nrorg = :P_NRORG
            AND r.NRAVALIACAO = :P_NRAVAL"
            );
        $sql->execute(        
            array(
            'P_NRORG' => $nrorg,
            'P_NRAVAL'=> $nravaliacao
            )
        );
        $return = $sql->fetchAll();
        if($return){
            return $return;
        }else{
            $sql = $this->entityManager->getConnection()->prepare(
                "SELECT r.*
                FROM COMBQUESTAVAL r
                WHERE r.nrorg = :P_NRORG
                AND r.NRAVALIACAO IS NULL"
                );
            $sql->execute(        
                array(
                'P_NRORG' => $nrorg
                )
            );
            $return = $sql->fetchAll();
            return $return;
        }
    }
    
    public function getVinculosAtivos($nrOrg, $dtCompetencia, $ds_inicio, $ds_fim, $dsOrdem){
            
        $ds_inicio = trim(strtoupper($ds_inicio));
        $ds_fim = trim(strtoupper($ds_fim));
        
        $dtUltDiaMes = explode("/", $dtCompetencia);
        $dtUltDiaMes[0] = cal_days_in_month(CAL_GREGORIAN,$dtUltDiaMes[1],$dtUltDiaMes[2]);
        $dtPrimDiaAno = "01/01/".$dtUltDiaMes[2];
        $dtUltDiaMes = $dtUltDiaMes[0].'/'.$dtUltDiaMes[1].'/'.$dtUltDiaMes[2];
        
        $condProcesso = '(GPE_VINCULOM.DTRESCISAOVINC IS NULL
                            OR GPE_VINCULOM.DTRESCISAOVINC > \'' . $dtUltDiaMes . '\'
                          )
                          AND ((GPE_VINCULOM.DTADMISSAOVINC <> GPE_VINCULOM.DTRESCISAOVINC) OR GPE_VINCULOM.DTRESCISAOVINC IS NULL)
                          AND GPE_VINCULOM.DTADMISSAOVINC <=  \'' . $dtUltDiaMes . '\'';
        switch ($dsOrdem){
            case 'ALFABETICA':
                $condIntervalo = 'TRIM(UPPER(GPE_VINCULOM.NMVINCULOM)) BETWEEN \''.$ds_inicio.'\' AND \''.$ds_fim.'\'';
                break;
            case 'ESTRUTURA':
                $condIntervalo = 'GPE_VINCULOH.NRESTRUTLEGAL = ' . $ds_inicio . ' ';
                $condIntervalo .= "AND (GPE_VINCULOH.NRESTRUTGEREN = '$ds_fim' OR '$ds_fim' IS NULL)";
                break;
            case 'MATRICULA':
                $condIntervalo = 'GPE_VINCULOM.CDMATRICULA BETWEEN \''.$ds_inicio.'\' AND \''.$ds_fim.'\'';
                break;
            case 'DATA_ADMISSAO':
                $condIntervalo = 'GPE_VINCULOM.DTADMISSAOVINC BETWEEN \''.$ds_inicio.'\' AND \''.$ds_fim.'\'';
                break;
        }
        $sql = 'SELECT MAXVINCH.DTMESCOMPETENC, GPE_VINCULOM.*
				  FROM GPE_VINCULOM
				  INNER JOIN
                      (SELECT MAX(DTMESCOMPETENC) DTMESCOMPETENC, NRVINCULOM, NRORG
                         FROM GPE_VINCULOH
                         WHERE DTMESCOMPETENC >= \''.$dtPrimDiaAno.'\'
						 AND DTMESCOMPETENC <= \''.$dtUltDiaMes.'\'
                         AND NRORG =  '.$nrOrg.'
                         GROUP BY NRVINCULOM, NRORG
                      ) MAXVINCH
                  ON MAXVINCH.NRVINCULOM = GPE_VINCULOM.NRVINCULOM
                  AND MAXVINCH.NRORG = GPE_VINCULOM.NRORG

                  INNER JOIN GPE_VINCULOH
				  ON GPE_VINCULOH.NRVINCULOM = MAXVINCH.NRVINCULOM
				  AND GPE_VINCULOH.DTMESCOMPETENC = MAXVINCH.DTMESCOMPETENC
				  AND GPE_VINCULOH.NRORG = MAXVINCH.NRORG
                 ';
        $where = ' WHERE ';
        if (empty($condProcesso) === false) {
            $where .= $condProcesso;
            $processo = true;
        }
        if (empty($condIntervalo) === false) {
            if ($processo === true) {
                $where .= ' AND ';
            }
            $where .= $condIntervalo;
        }
        $sql .= $where;
        $sql = $this->entityManager->getConnection()->prepare($sql);
        $sql->execute();
        $resultado = $sql->fetchAll();
        return $resultado;
        }
    
    public function getHierarquia($nrorg, $nrorg_padrao, $nrtipohierarqorg){
        $sql = $this->entityManager->getConnection()->prepare(
            "SELECT r.*
            FROM TIPOHIERARQORG r
            WHERE (r.nrorg = :P_NRORG OR r.nrorg = :P_NRORG_PADRAO)
            AND r.NRTIPOHIERARQORG = :P_TIPOHIERARQORG"
            );
        $sql->execute(        
            array(
            'P_NRORG' => $nrorg,
            'P_NRORG_PADRAO' => $nrorg_padrao,
            'P_TIPOHIERARQORG'=> $nrtipohierarqorg
            )
        );
        return $sql->fetchAll();   
    }
    
    public function getUltimoHistoricoCompetencia($nrorg,$nrvinculom,$mescompetencia){
         $sql = $this->entityManager->getConnection()->prepare(
        "SELECT * FROM GPE_VINCULOH WHERE
            NRORG = :P_NRORG
            AND NRVINCULOM     = :P_NRVINCULOM
            AND DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC)
                                 FROM GPE_VINCULOH
                                WHERE NRORG = :P_NRORG
                                  AND NRVINCULOM = :P_NRVINCULOM
                                  AND DTMESCOMPETENC <= :P_DTMESCOMPETENC)"
        );
        $sql->execute(
            array(
                'P_NRORG' => $nrorg, 
                'P_NRVINCULOM' => $nrvinculom,
                'P_DTMESCOMPETENCIA' => $dtmescompetencia
            )
        );
        return $sql->fetchAll();
    }
    
    public function getUltimaMovimentacaoPorTipo($nrorg, $nrtipoestrutura, $nrvinculom){
        $sql = $this->entityManager->getConnection()->prepare(
        "
        SELECT * FROM GPE_MOVIMENTACAO WHERE
        NRORG = :P_NRORG
        AND NRTIPOESTRUTURA = :P_NRTIPOESTRUTURA
        AND NRVINCULOM = :P_NRVINCULOM
        AND DTINIMOVIMENT = (SELECT MAX(DTINIMOVIMENT)
                                  FROM GPE_MOVIMENTACAO
                                 WHERE NRORG = :P_NRORG
                                   AND NRTIPOESTRUTURA = :P_NRTIPOESTRUTURA
                                   AND NRVINCULOM = :P_NRVINCULOM)"
        );
        $sql->execute(
            array(
                "P_NRORG" => $nrorg,
                "P_NRTIPOESTRUTURA" => $nrtipoestrutura,
                "P_NRVINCULOM" => $nrvinculom
                )
            );

        return $sql->fetchAll();
    }
    
    public function getNrParcRespInf($nrorg,$nrestruturam){
        $sql = $this->entityManager->getConnection()->prepare(
        "
SELECT NRPARCRESPINF
  FROM ESTRUTURAH 
 WHERE NRORG = :P_NRORG
       AND NRESTRUTURAM = :P_NRESTRUTURAM
       AND DTMESCOMPETENC = (SELECT MAX(EH.DTMESCOMPETENC) 
                               FROM ESTRUTURAH EH
                              WHERE EH.NRORG = :P_NRORG
                                    AND EH.NRESTRUTURAM = :P_NRESTRUTURAM)
        ");
        $sql->execute(
            array(
                "P_NRORG" => $nrorg,
                "P_NRESTRUTURAM" => $nrestruturam
                )
            );
        return $sql->fetchAll();
    }
    
    public function getPessoa($nrorg, $nrpessoa){
        $sql = $this->entityManager->getConnection()->prepare(
        "
        SELECT * FROM GPE_PESSOA 
        WHERE NRORG = :P_NRORG
        AND NRPESSOA = :P_NRPESSOA
        ");
        $sql->execute(
            array(
                "P_NRORG" => $nrorg,
                "P_NRPESSOA" => $nrpessoa
                )
            );
        return $sql->fetchAll();
    }
    
    public function getTipoRelaciona($nrtiporelaciona){
         $sql = $this->entityManager->getConnection()->prepare(
        "
        SELECT * FROM TIPORELACIONA 
        WHERE NRTIPORELACIONA = :P_NRTIPORELACIONA
        ");
        $sql->execute(
            array(
                "P_NRTIPORELACIONA" => $nrtiporelaciona
                )
            );
        return $sql->fetchAll();
    }
    
    public function getParticipaval($nrorg, $nravaliacao, $nrcombquestaval, $nrtiporelaciona, $avaliador, $avaliado){
   
        $sql = $this->entityManager->getConnection()->prepare(
        "
        SELECT * FROM PARTICIPAVAL 
        WHERE NRORG = :P_NRORG
        AND NRAVALIACAO = :P_NRAVALIACAO
        AND NRCOMBQUESTAVAL = :P_NRCOMBQUESTAVAL
        AND NRTIPORELACIONA = :P_NRTIPORELACIONA
        AND NRPARCEXECAVAL = :P_AVALIADOR
        AND NRPARCAVALIADO = :P_AVALIADO
        ");
        $sql->execute(
            array(
                "P_NRORG" => $nrorg,
                    "P_NRAVALIACAO" => $nravaliacao,
                    "P_NRCOMBQUESTAVAL" => $nrcombquestaval,
                    "P_NRTIPORELACIONA" => $nrtiporelaciona,
                    "P_AVALIADOR" => $avaliador,
                    "P_AVALIADO" => $avaliado
                )
            );
        return $sql->fetchAll();
    }
    
    public function getTipoRelacionaByName($nrorg,$nmtiporelaciona){
         $sql = $this->entityManager->getConnection()->prepare(
        "
        SELECT * FROM TIPORELACIONA 
        WHERE NRORG = :P_NRORG
        AND NMTIPORELACIONA = :P_NMTIPORELACIONA
        ");
        $sql->execute(
            array(
                "P_NRORG" => $nrorg,
                "P_NMTIPORELACIONA" => $nmtiporelaciona
                )
            );
        
    }
    public function consultaParticipantesLibera($nravaliacao, $nrorg){
        $sql = $this->entityManager->getConnection()->prepare(
         "SELECT AVALIACAOGERAL.NRAVALIACAO, QUESTAVALIACAO.NRQUESTAO, QUESTAVALIACAO.NRCOMBQUESTAVAL,
                        PARTICIPAVAL.NRPARCAVALIADO, PARTICIPAVAL.NRPARCEXECAVAL
                   FROM QUESTAVALIACAO,AVALIACAOGERAL,COMBQUESTAVAL,QUESTAO, PARTICIPAVAL
                  WHERE QUESTAO.NRQUESTAO = QUESTAVALIACAO.NRQUESTAO
                    AND COMBQUESTAVAL.NRCOMBQUESTAVAL = QUESTAVALIACAO.NRCOMBQUESTAVAL
                    AND (COMBQUESTAVAL.NRAVALIACAO    = AVALIACAOGERAL.NRAVALIACAO OR COMBQUESTAVAL.NRAVALIACAO IS NULL)
                    AND PARTICIPAVAL.NRCOMBQUESTAVAL  = COMBQUESTAVAL.NRCOMBQUESTAVAL
                    AND AVALIACAOGERAL.NRAVALIACAO    = PARTICIPAVAL.NRAVALIACAO
                    AND AVALIACAOGERAL.NRAVALIACAO    = QUESTAVALIACAO.NRAVALIACAO
                    AND AVALIACAOGERAL.NRORG          = QUESTAVALIACAO.NRORG
                    AND COMBQUESTAVAL.NRORG           = QUESTAVALIACAO.NRORG
                    AND QUESTAO.NRORG                 = QUESTAVALIACAO.NRORG
                    AND PARTICIPAVAL.NRORG            = QUESTAVALIACAO.NRORG
                    AND AVALIACAOGERAL.NRAVALIACAO    = :P_NRAVALIACAO
                    AND QUESTAVALIACAO.NRORG          = :P_NRORG
                    AND PARTICIPAVAL.NRPARCAVALIADO NOT IN (SELECT DISTINCT EXECAVALIACAO.NRPARCAVALIADO
                                    FROM EXECAVALIACAO, PARTICIPAVAL
                                    WHERE PARTICIPAVAL.NRPARCAVALIADO  = EXECAVALIACAO.NRPARCAVALIADO
                                      AND PARTICIPAVAL.NRPARCEXECAVAL  = EXECAVALIACAO.NRPARCEXECAVAL
                                      AND PARTICIPAVAL.NRCOMBQUESTAVAL = EXECAVALIACAO.NRCOMBQUESTAVAL
                                      AND PARTICIPAVAL.NRAVALIACAO     = EXECAVALIACAO.NRAVALIACAO
                                      AND EXECAVALIACAO.NRAVALIACAO    = :P_NRAVALIACAO)");
        $sql->execute( 
            array(
            "P_NRAVALIACAO" => $nravaliacao, 
            "P_NRORG" => $nrorg
            )
        );
        
        return $sql->fetchAll();
    }
    
    public function contaParticipantes($params){
         $sql = $this->entityManager->getConnection()->prepare(
         "SELECT AVALIACAOGERAL.NRAVALIACAO, PARTICIPAVAL.NRPARCAVALIADO, PARTICIPAVAL.NRPARCEXECAVAL
                            FROM AVALIACAOGERAL,COMBQUESTAVAL,PARTICIPAVAL
                            WHERE (COMBQUESTAVAL.NRAVALIACAO = AVALIACAOGERAL.NRAVALIACAO OR COMBQUESTAVAL.NRAVALIACAO IS NULL)
                            AND PARTICIPAVAL.NRCOMBQUESTAVAL = COMBQUESTAVAL.NRCOMBQUESTAVAL
                            AND AVALIACAOGERAL.NRAVALIACAO   = PARTICIPAVAL.NRAVALIACAO
                            AND COMBQUESTAVAL.NRORG          = AVALIACAOGERAL.NRORG
                            AND PARTICIPAVAL.NRORG           = AVALIACAOGERAL.NRORG
                            AND AVALIACAOGERAL.NRAVALIACAO   = :P_NRAVALIACAO
                            AND AVALIACAOGERAL.NRORG         = :P_NRORG
                            AND PARTICIPAVAL.NRCOMBQUESTAVAL NOT IN (:P_NRCOMBQUESTAVAL)
                            AND NOT EXISTS (SELECT EXECAVALIACAO.NRPARCAVALIADO, EXECAVALIACAO.NRPARCEXECAVAL, EXECAVALIACAO.NRCOMBQUESTAVAL, 			    EXECAVALIACAO.NRAVALIACAO
                             FROM EXECAVALIACAO
                             WHERE PARTICIPAVAL.NRPARCAVALIADO = EXECAVALIACAO.NRPARCAVALIADO
                             AND PARTICIPAVAL.NRPARCEXECAVAL   = EXECAVALIACAO.NRPARCEXECAVAL
                             AND PARTICIPAVAL.NRCOMBQUESTAVAL  = EXECAVALIACAO.NRCOMBQUESTAVAL
                             AND PARTICIPAVAL.NRAVALIACAO      = EXECAVALIACAO.NRAVALIACAO)");
        $sql->execute($params);
        return $sql->fetchAll();
     }
    
    public function quantidadeCombAval($nravaliacao, $nrorg){
        $sql = $this->entityManager->getConnection()->prepare(
            "SELECT DISTINCT PARTICIPAVAL.NRCOMBQUESTAVAL, COMBQUESTAVAL.NMCOMBQUESTAVAL FROM PARTICIPAVAL, COMBQUESTAVAL WHERE PARTICIPAVAL.NRCOMBQUESTAVAL = COMBQUESTAVAL.NRCOMBQUESTAVAL AND  PARTICIPAVAL.NRAVALIACAO = :P_NRAVALIACAO AND PARTICIPAVAL.NRORG = :P_NRORG"    
        );
        
        $sql->execute(
            array(
                "P_NRAVALIACAO" => $nravaliacao,
                "P_NRORG" => $nrorg    
            )
        );
        return $sql->fetchAll();
    }
    
    public function questCombinacao($nravaliacao, $combinacao){
        $sql = $this->entityManager->getConnection()->prepare(
            "SELECT * FROM QUESTAVALIACAO WHERE NRAVALIACAO = :P_NRAVALIACAO AND NRCOMBQUESTAVAL = :P_NRCOMBQUESTAVAL"  
        );
        $sql->execute(
            array(
                "P_NRAVALIACAO" => $nravaliacao,
                "P_NRCOMBQUESTAVAL" => $combinacao
            )    
        );
        return $sql->fetchAll();
        

    }

} 