<?php

namespace HCM\FPA\Controllers;

use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Doctrine\DBAL\Connection;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use HCM\Util\HCMParameters;
use HCM\Util\FPA;
use HCM\Util\Repositories;
use Doctrine\ORM\EntityManager;
use HCM\Util\DateUtil;
use HCM\Geral\Controllers\RelatoriosHcmController;

class CNABLeituraController extends Crud {

    protected $dataSource = 'fpa_setRetornoCNAB';
    protected $dataSourceNameGet = 'fpa_getRetornoCNAB';
    protected $parameterBagColumns = array('P_NRORG');

    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, HCMParameters $hcmParameters, EntityManager $entityManager, Connection $connection, \HCM\FPA\Services\CNABLeituraService $cnabLeituraService, RelatoriosHcmController $relatoriosHcmController){
        $this->parameterBag = $parameterBag;
        $this->hcmParameters = $hcmParameters;
        $this->entityManager = $entityManager;
        $this->connection = $connection;        
        $this->cnabLeituraService = $cnabLeituraService;
        $this->relatoriosHcmController = $relatoriosHcmController;
        parent::__construct($dataSourceManager);
    }

    public function getRetornoCnab (DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceNameGet);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData); 
        $response->addDataSet($dataSet);
    }

    public function leituraCNAB(DTO\Request\DataSet $request, DTO\Response $response) {
        try{
            $row = $request->getDataSet()->getRows();
            $row = $row[0];
            $data = array();
            $message = array();
            foreach ($row['DSPATH'] as $arquivo) {
                $row['DSPATH'] = [$arquivo];

                switch($row['BANCO']) {
                    case 'BRADESCO':
                        if($row['POSICOES'] == 200) {
                            $data = $this->cnabLeituraService->leituraArquivoBradesco200($row);
                        } else {
                            $data = $this->cnabLeituraService->leituraArquivoBradesco240($row);
                        }
                        break;
                    default:
                        $message = new \Zeedhi\Framework\DTO\Response\Message('Banco inválido', 'E');
                        $response->addMessage($message);
                        break;
                }
            }

            if(array_key_exists('erro', $message)) {
                $message = new \Zeedhi\Framework\DTO\Response\Message($message['erro'], 'E');
                $response->addMessage($message);
            }
            if($data['sucesso']) {
                $message = new \Zeedhi\Framework\DTO\Response\Message($data['sucesso'], 'S');
                $response->addMessage($message);
                unset($data['sucesso']);

                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('data', $data));
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
        
    }

    public function salvarRegistrosRetornoCNAB(DTO\Request\DataSet $request, DTO\Response $response) {
        try{
            $this->dataSourceName = $this->dataSource;
            $rows = $request->getDataSet()->getRows();
        
            $nmArquivo = $rows[0]['NMARQUIVO'];
            $nrorg = $this->hcmParameters->getNrorgTrabalho();
            $cdoperador = $this->hcmParameters->getCdoperador();
            
            if(!empty($this->cnabLeituraService->verificaExistenciaArquivo($nmArquivo, $nrorg))) {
                $message = new \Zeedhi\Framework\DTO\Response\Message('Arquivo já existente!', 'E');
                $response->addMessage($message);
            } else {
                foreach($rows as $row) {
                    if (array_key_exists('NRRETORNOCNAB', $row)) {
                        if ($row['NRRETORNOCNAB'] === '') {
                            $row['NRRETORNOCNAB'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'FPA_RETORNOCNAB', 1, 12, true);
                        }
                    } else {
                        $row['NRRETORNOCNAB'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'FPA_RETORNOCNAB', 1, 12, true);
                    }

                    $row['DTINCLUSAO'] = DateUtil::getDataAtual()->format('d/m/Y');
                    $row['DTULTATU'] = DateUtil::getDataAtual()->format('d/m/Y');
                    $row['NRORGINCLUSAO'] = $nrorg;
                    $row['CDOPERINCLUSAO'] = $cdoperador;
                    $row['NRORGULTATU'] = $nrorg;
                    $row['CDOPERULTATU'] = $cdoperador;
                    $row['NRORG'] = $nrorg;

                    $this->incluiCamposFaltantes($row);
                }
                parent::save($request, $response);
                /*gera relatorio pagto eletronico*/
                $filtro = array(
                    'P_NMARQUIVO'     => $nmArquivo,
                    'P_NRORG'         => $nrorg,
                    'P_DTPAGAMENTO'   => $row['DTPAGAMENTO'],
                    'P_CDBANCO'       => $row['BANCO'],
                    'P_COMPETENCIA'   => $this->hcmParameters->getDtCompetencia(),
                );
               $caminhoReport[] =  $this->relatoriosHcmController->setRelatoriosHcmBackend($filtro, 'pagto_eletronico_cnab', $request, $response);
               $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('report', $caminhoReport));
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function GeraRelatPagamento(DTO\Request\DataSet $request, DTO\Response $response) {
        try{
            $this->dataSourceName = $this->dataSource;
            $rows = $request->getDataSet()->getRows();
            $nrorg = $this->hcmParameters->getNrorgTrabalho();
            $cdoperador = $this->hcmParameters->getCdoperador();
            foreach($rows as $row) {
                if(!isset($row['NMARQUIVO'])){
                    $row['NMARQUIVO'] = "";
                }
                if(!isset($row['DTPAGAMENTO'])){
                    $row['DTPAGAMENTO'] = "";
                }
                $filtro = array(
                    'P_NMARQUIVO'     => $row['NMARQUIVO'],
                    'P_DTPAGAMENTO'   => $row['DTPAGAMENTO'],
                    /*'P_CDBANCO'       => $row['BANCO'],*/
                    'P_NRORG'         => $nrorg,
                    'P_COMPETENCIA'   => $this->hcmParameters->getDtCompetencia(),
                );
               $caminhoReport[] =  $this->relatoriosHcmController->setRelatoriosHcmBackend($filtro, 'pagto_eletronico_cnab', $request, $response);
               $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('report', $caminhoReport));
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    private function incluiCamposFaltantes(&$row) {
        if(empty($row['CODIGO'])) {
            $row['CODIGO'] = null;
        }
        if(empty($row['DTRETORNO'])) {
            $row['DTRETORNO'] = null;
        }
        if(empty($row['NMEMPRESA'])) {
            $row['NMEMPRESA'] = null;
        }
        if(empty($row['CNPJEMPRESA'])) {
            $row['CNPJEMPRESA'] = null;
        }
        if(empty($row['CONTAEMPRESA'])) {
            $row['CONTAEMPRESA'] = null;
        }
        if(empty($row['AGENCIAEMPRESA'])) {
            $row['AGENCIAEMPRESA'] = null;
        }
    }

    protected function processConditionValue($condition) {
        return $condition['value'];
    }
    protected function populateParameterBag(FilterCriteria $filterCriteria) {

        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }
        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );
        return $newFilterCriteria;
    }
}