<?php

namespace HCM\FPA\Controllers;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use HCM\Util\HCMParameters;
use HCM\Util\DateUtil;
use HCM\FPA\Calculos\Geral\Inicializa;
use HCM\FPA\Services\ProgramacaoFeriasService;
use HCM\Geral\Services\CalendarioService;
use HCM\FPA\Entity\FpagozoferiasEntity;
use HCM\FPA\Entity\FpaferiasEntity;
use HCM\Geral\Entity\GpevinculomEntity;
use HCM\Util\Util;

class ProgramacaoFeriasController extends Crud {

    protected $dataSource = 'fpa_formferias';
    protected $dataSourceGet = 'getVinculosProgFerias';
    protected $dataSourceGet_iteCalc = 'getItecalcfolhaProgFerias';

    protected $parameterBagColumns = array('P_NRORG', 'P_NRORG_PADRAO', 'P_ULTIMODIAMES', 'P_RESCISAO', 'P_CDOPERADOR', 'P_NRVINCULOM', 'P_NRESTRUTLEGAL', 'P_NRESTRUTGEREN', 'P_DTMESCOMPETENC', 'P_NRCALCULOFOLHA', 'P_NRTIPOMOVIMENT');

    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, HCMParameters $hcmParameters, entityManager $entityManager, ProgramacaoFeriasService $progFeriasService, CalendarioService $calendarioService){
        parent::__construct($dataSourceManager);
        $this->parameterBag = $parameterBag;
        $this->hcmParameters = $hcmParameters;
        $this->entityManager = $entityManager;
        $this->progFeriasService = $progFeriasService;
        $this->calendarioService = $calendarioService;
    }
    
    public function getItecalcfolhaProgFerias (DTO\Request\Filter $request, DTO\Response $response) {
        set_time_limit(0);
        ini_set('memory_limit', '2048M');

        $filterData = $request->getFilterCriteria();
        foreach($filterData->getConditions() as $condition) {
            if($condition['columnName'] == 'P_NRTIPOMOVIMENT') {
                $nrtipomoviment = $condition['value'];
            }
        }
        $filterData->addCondition('P_ULTIMODIAMES','=',$this->hcmParameters->getUltimoDiaMes());
        $filterData->addCondition('P_NRORG_PADRAO','=',$this->hcmParameters->getNrorgPadrao());
        $filterData->addCondition('P_NRCALCULOFOLHA','=',$this->hcmParameters->determinaNrCalculoFolha($nrtipomoviment));
        $filterData->setDataSourceName($this->dataSourceGet_iteCalc);
        $filterData->setPageSize(9999);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    
    public function getVinculosProgFerias(DTO\Request\Filter $request, DTO\Response $response) {
        set_time_limit(0);
        ini_set('memory_limit', '2048M');
        
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceGet);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $rows = $dataSet->getRows();
        
        $rows = $this->progFeriasService->atualizarValoresGozo($rows);
        
        $response->addDataSet(new DataSet($this->dataSourceGet, $rows));
    }
    
    public function setGozoFeriasInline (DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            error_reporting(E_ERROR | E_PARSE);
            foreach ($request->getDataSet()->getRows() as &$rows) {
                
                $this->progFeriasService->saveGozoFeriasInline($rows);
                
                $message = new \Zeedhi\Framework\DTO\Response\Message('Registro salvo com sucesso', DTO\Response\Message::TYPE_MESSAGE);
                $response->addMessage($message);
                
            }
            
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    //Valida a programação de ferias se é um feriado.
    public function validaProgFeriasFeriado (DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $validaData = $this->calendarioService->isDataFeriadoVinculos($request->getDataSet()->getRows());
            $response->addDataSet(new DataSet('validaProgFeriasFeriado', $validaData));
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    //Valida a programação de ferias se é ja existe um gozo de ferias.
    public function verificaGozoJaCadastrado (DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $validaGozo = $this->progFeriasService->verificaGozoJaCadastrado($request->getDataSet()->getRows());
            $response->addDataSet(new DataSet('verificaGozoJaCadastrado', $validaGozo));
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    //Valida a programação de ferias se é um feriado.
    public function validaDataInicio (DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $validaData = $this->progFeriasService->verificaDataInicio($request->getDataSet()->getRows());
            $response->addDataSet(new DataSet('validaDataInicio', $validaData));
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    protected function processConditionValue($condition) {
        return $condition['value'];
    }

    protected function populateParameterBag(FilterCriteria $filterCriteria) {
        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }
        
        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );

        return $newFilterCriteria;
    }
}