<?php

namespace HCM\Geral\Controllers;

use HCM\Geral\Services\PessoaService;
use HCM\Geral\Services\CrudService;
use HCM\Geral\Services\ESocialService;
use HCM\Util\HCMParameters;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use Doctrine\ORM\EntityManager;
use HCM\Geral\Controllers\ParceiroNegocioController;
use Zeedhi\Framework\DTO\Response\Notification;
use HCM\Util\Util;
use HCM\Util\Repositories;
use HCM\Util\Messages;
use HCM\Util\DateUtil;

class PessoaController extends Crud {
    
    protected $dataSourceName_get = 'getPessoa';
    protected $dataSourceNameMedDent_get = 'getPessoaConselhoReg';
    protected $dataSourceNameResponsavel_get = 'getPessoaResponsavel';
    protected $parameterBagColumns = array('P_NRORG_PADRAO','P_NRORG','P_DTMESCOMPETENC','EXISTE_VINCULOS','IDATIVO','EXISTE_ADMPRELIMINAR');
    protected $nmArquivoTemplateCon = 'contaCorrente';
    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, HCMParameters $hcmParameters, PessoaService $pessoaService,CrudService $crudService, ParceiroNegocioController $parceiroNegocioController, EntityManager $entityManager, ESocialService $eSocialService){
        $this->parameterBag = $parameterBag;
        parent::__construct($dataSourceManager);
        $this->hcmParameters = $hcmParameters;
        $this->pessoaService = $pessoaService;
		$this->crudService = $crudService;
		$this->entityManager = $entityManager;
		$this->eSocialService = $eSocialService;
		$this->parceiroNegocioController = $parceiroNegocioController;
    }
    
    public function baixarPlanilhaContaCorrente(DTO\Request\DataSet $request, DTO\Response $response) {
    try{
        $file = $this->pessoaService->baixarPlanilhaContaCorrente(
            $this->hcmParameters->getNrorgTrabalho(),
            $this->nmArquivoTemplateCon);
            

        if($file != null){
            $retorno = array('NMARQUIVO' => $file);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('arquivo', $retorno));
        }
        
    } catch(\Exception $e) {
        $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /*public function importarPlanilhaContaCorrente(DTO\Request\DataSet $request, DTO\Response $response) {
        set_time_limit(0);
        
        try{
            $row = $request->getDataSet()->getRows();
            $row = $row[0];
            
            $messages = $this->pessoaService->importarPlanilhaContaCorrente($row);
            if(empty($messages)){
                $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("Operação concluida com sucesso.", \Zeedhi\Framework\DTO\Response\Message::TYPE_MESSAGE));
            } else {
                $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message("Operação concluida. Existem erros na importação", \Zeedhi\Framework\DTO\Response\Message::TYPE_WARNING));
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('msg', $messages));
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }*/
    
    public function getPessoa(DTO\Request\Filter $request, DTO\Response $response) {
        set_time_limit(0);
        ini_set('memory_limit', '3072M');
        
        $recisaofiltro = false;
        $admPrefiltro = false;
        $filterData = $request->getFilterCriteria();
        foreach ($filterData->getConditions() as $value) {
            if($value['columnName'] == "EXISTE_VINCULOS")
                $recisaofiltro = true;
            if($value['columnName'] == "EXISTE_ADMPRELIMINAR")
                $admPrefiltro = true;
        }
        if(!$recisaofiltro)
            $filterData->addCondition('EXISTE_VINCULOS','=', 'S');
        if(!$admPrefiltro)
            $filterData->addCondition('EXISTE_ADMPRELIMINAR','=', 'N');
        $filterData->setDataSourceName($this->dataSourceName_get);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    
    public function getPessoaResponsavel (DTO\Request\Filter $request, DTO\Response $response){
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceNameResponsavel_get);
        $filterData->setPageSize(99999);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    
    public function getRacaPessoa(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName('getRacaPessoa');
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    
    public function getPessoaConselhoReg(DTO\Request\Filter $request, DTO\Response $response){
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceNameMedDent_get);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    
    public function getPessoaRelacionamentos(DTO\Request\Filter $request, DTO\Response $response)
    {
        try{
            $filters = $request->getFilterCriteria()->getConditions();
            $idpessoaprinc = 'S';
            $nrtiporelaciona = '';
            $nrpessoa = '';
            
            foreach ($filters as $filter) {
                if($filter['columnName'] === 'NRPESSOA'){
                    $nrpessoa = $filter['value'];
                }
                if($filter['columnName'] === 'IDPESSOAPRINC'){
                    $idpessoaprinc = $filter['value'];
                }
                if($filter['columnName'] === 'NRTIPORELACIONA'){
                    $nrtiporelaciona = $filter['value'];
                }
            }
            
            Util::getValueInFilterDataSourceByName($filters, array('NRPESSOA', 'IDPESSOAPRINC', 'NRTIPORELACIONA', 'P_NRORG_PADRAO'), true);
            $conditions = Util::createQueryFiltered($filters);
            $nrorg = $this->hcmParameters->getNrorgTrabalho();
            $dtmescompetenc = $this->hcmParameters->getDtCompetencia();
            $nrorgpadrao = $this->hcmParameters->getNrorgPadrao();
            if ($nrtiporelaciona != '') {
                $parameters = array($nrorg,$dtmescompetenc,$nrorgpadrao,$nrpessoa,$idpessoaprinc, $nrtiporelaciona);
            } else {
                $parameters = array($nrorg,$dtmescompetenc,$nrorgpadrao,$nrpessoa,$idpessoaprinc);
            }
            $result = $this->pessoaService->getPessoaRelacionamentos($parameters, $conditions);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getPessoaRelacionamentos', $result));
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function setPessoa($request, $response) {
		try {
		    $message = '';
		    //validaPessoa
		    foreach ($request->getDataSet()->getRows() as &$row) {
	            if($row['__is_new'] === true){
                    $message = $this->pessoaService->validaCpfExistePessoa($row, false);
                    if($message){
                        throw new \Exception($message, 10);
                    }
                }else{
                    $message = $this->pessoaService->validaPessoaVinculo($row, false);
                }
		    }
		    //Salva o parceiro de negocio e retorna o NRPARCNEGOCIO para ser salvo na tabela de Pessoa
		    $this->parceiroNegocioController->setParcNegocio($request, $response);
		    if(!empty($response->getDataSets())){
    		    foreach ($request->getDataSet()->getRows() as &$row) {
    		        $row["NRPARCNEGOCIO"] = $response->getDataSets()[0]->getRows()[0]["NRPARCNEGOCIO"];
                    $row['NMPESSOA'] = trim($row['NMPESSOA']);
                    if(!array_key_exists('SGUFCTPSPES', $row)){
                        $row['SGUFCTPSPES'] = null;
                    }
                    if(!array_key_exists('SGUFCONSREG', $row)){
                        $row['SGUFCONSREG'] = null;
                    }
                    if(!array_key_exists('CDPAIS', $row)){
                        $row['CDPAIS'] = null;
                    }
                    if(!array_key_exists('SGESTADO', $row)){
                        $row['SGESTADO'] = null;
                    }
                    if(!array_key_exists('CDMUNICIPIO', $row)){
                        $row['CDMUNICIPIO'] = null;
                    }
                    if(!array_key_exists('CDTPBAIXAPAG', $row)){
                        $row['CDTPBAIXAPAG'] = null;
                    }
                    if(!array_key_exists('SGUFRGPESSOA', $row)){
                        $row['SGUFRGPESSOA'] = null;
                    }
                    if(!array_key_exists('NRGRAUINSTR', $row)){
                        $row['NRGRAUINSTR'] = null;
                    }
                    if(!array_key_exists('DSCAMINHOFOTO', $row)){
                        $row['DSCAMINHOFOTO'] = null;
                    }
                    if(!array_key_exists('IDPOSSUIFILHO', $row)){
                        $row['IDPOSSUIFILHO'] = 'N';
                    }
                    if(!array_key_exists('DSCAMINHOFOTO', $row)){
                        $row['DSCAMINHOFOTO'] = null;
                    }
                    if(!array_key_exists('NRIDADEFILHO', $row)){
                        $row['NRIDADEFILHO'] = null;
                    }
                    if(!array_key_exists('NRCONDFISPES', $row)){
                        $row['NRCONDFISPES'] = null;
                    }
                    if(!array_key_exists('NRCATMILITARPE', $row)){
                        $row['NRCATMILITARPE'] = null;
                    }
                    if(!array_key_exists('NRCONSELHOREG', $row)){
                        $row['NRCONSELHOREG'] = null;
                    }
                    if(!array_key_exists('CDESTACIVIL', $row)){
                        $row['CDESTACIVIL'] = null;
                    }
                    if(!array_key_exists('NRRACAPESSOA', $row)){
                        $row['NRRACAPESSOA'] = null;
                    }
                    if(!array_key_exists('NRANOCHEGAPAIS', $row)){
                        $row['NRANOCHEGAPAIS'] = null;
                    }
                    if(!array_key_exists('DTADMISSAOPRE', $row)){
                        $row['DTADMISSAOPRE'] = null;
                    }
                    if(!array_key_exists('CDRECIBOADMPRE', $row)){
                        $row['CDRECIBOADMPRE'] = null;
                    }
                    if(array_key_exists('NRCPFPESSOA', $row)){
                        $row['NRCPFPESSOA'] = str_replace('.', '', $row['NRCPFPESSOA']);
                        $row['NRCPFPESSOA'] = str_replace('-', '', $row['NRCPFPESSOA']);
                    }
                    if(array_key_exists('NRPISPASEPPES', $row)){
                        $row['NRPISPASEPPES'] = str_replace('.', '', $row['NRPISPASEPPES']);
                        $row['NRPISPASEPPES'] = str_replace('-', '', $row['NRPISPASEPPES']);
                    }
                    
                    $row['SGUFHABCARPES'] = isset($row['SGUFHABCARPES'])?$row['SGUFHABCARPES']:null;
                    $row['SGESTADO'] = isset($row['SGESTADO'])?$row['SGESTADO']:null;
                    $row['DSEXPDOCESTR'] = isset($row['DSEXPDOCESTR'])?$row['DSEXPDOCESTR']:null;
                    $row['NRCLASSESTRANG'] = isset($row['NRCLASSESTRANG'])?$row['NRCLASSESTRANG']:null;
                    $row['NRSUSPESSOA'] = isset($row['NRSUSPESSOA'])?$row['NRSUSPESSOA']:null;
                    $row['NRNITPESSOA'] = isset($row['NRNITPESSOA'])?$row['NRNITPESSOA']:null;
                    $row['IDCOTAPCD'] = isset($row['IDCOTAPCD'])?$row['IDCOTAPCD']:null;
                    
                    
                    $nomesPessoa = $this->pessoaService->decompoeNomePessoa($row['NMPESSOA']);
                    $row['DSPRINOMEPESS'] = $nomesPessoa[0];
                    $row['DSNOMEMEIOPESS'] = $nomesPessoa[1];
                    $row['DSULTNOMEPESS'] = $nomesPessoa[2];
    		    }
    		    
    			$this->dataSourceName = 'gpe_pessoa';
    			$this->dataSourceNameToSave = $this->crudService->getDataSourceNameToSaveByName($this->dataSourceName);
    			$this->dataSourceName = $this->dataSourceNameToSave ? $this->dataSourceNameToSave : $this->dataSourceName;
    			$rows = $this->crudService->getRowsToSave($request, $this->dataSourceName);
    			$this->crudService->save($this->dataSourceName, $rows);
    			
    			$request = $this->crudService->buildDataSetIfRow($request, $this->dataSourceName);
    			
    			$currentRow = current($request->getDataSet()->getRows());
    			
    			$mensagemAlertaHistorico = null;
    			$dtmescompetenc = $this->hcmParameters->getDtCompetencia();
    			$dtmescompetenc = DateUtil::getDataDeString( substr($dtmescompetenc, 0, 10) );
        		$dtmescompetenc = DateUtil::truncateData( $dtmescompetenc );
    			$pessoah = $this->entityManager->getRepository(Repositories::GPE_PESSOAH)->findOneBy(array('nrpessoa' => $row['NRPESSOA'], 'nrorg' => $row['NRORG'], 'dtmescompetenc' => $dtmescompetenc ));
		        if($pessoah && $pessoah->getNrpessoah() != $row['NRPESSOAH']){
		            $mensagemAlertaHistorico = "Operação bloqueada! Favor atualizar os dados da tela antes de prosseguir com a respectiva atualização.";
		        }
    
    			if(isset($currentRow['saveHistoryTable']) && empty($mensagemAlertaHistorico)) {
    
                    if (!$currentRow['__is_new']) {
                        
                        if (!$this->checkHistory($response, $currentRow)) {
                            // is new history
                            
                            $currentRow['__is_new'] = true;
                        }
                    }
    				$tableMasterPK = strtoupper($currentRow['saveHistoryTable']['__table_master_pk']);
    				$newCode = array_filter($this->crudService->getColumnsToReturn(), function ($element) use ($tableMasterPK) {
    					return $element[$tableMasterPK];
    				});
    
    				$this->dataSourceNameToSave = $this->crudService->getDataSourceNameToSaveByName($currentRow['saveHistoryTable']['__table_history_name']);
    				$this->dataSourceName = $this->dataSourceNameToSave ? $this->dataSourceNameToSave : $this->dataSourceName;
    				$currentRow[strtoupper($currentRow['saveHistoryTable']['__table_master_pk'])] = intval($newCode[0][strtoupper($currentRow['saveHistoryTable']['__table_master_pk'])]);
                    
                    // set history properties
                    $currentRow['__new_code_pk'] = $currentRow['saveHistoryTable']['__table_history_name'];
                    $currentRow['__table_pk'] = $currentRow['saveHistoryTable']['__table_history_pk'];
    
    	        	$newDataSet = new DataSet($this->dataSourceName, array($currentRow));
    	        	$newRequest = new \Zeedhi\Framework\DTO\Request\DataSet($newDataSet,
    	            $request->getMethod(), $request->getRoutePath(), $request->getUserId());
    				$rows = $this->crudService->getRowsToSave($newRequest, $this->dataSourceName);
    				$this->crudService->save($this->dataSourceName, $rows);
                }
                if ($mensagemAlertaHistorico) {
                    $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message($mensagemAlertaHistorico, DTO\Response\Message::TYPE_ERROR));
                } else if ($message) {
    			    $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message($message, DTO\Response\Message::TYPE_WARNING));
    			} else if (array_key_exists('IDENVIAESOCIAL', $row) && $row['IDENVIAESOCIAL'] == 'S') {
                    $this->eSocialService->envioEsocialDescentralizado($row, $response);
                }
			}
			$response->addDataset(new DataSet('columnsToReturn', $this->crudService->getColumnsToReturn()));
		} catch (\Exception $e) {
		    if ($e->getCode() === 10) {
                $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            }
			else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
 	        }
		}
	}
    
    public function getRelacionamentoParc(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = "relacionaparc_get";
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    
    public function getClasseEstrang(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = "gpe_classeestrang_get";
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    
    public function setRelacionamentoParc(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $this->dataSourceName = "relacionaparc";
            $jaExistente = null;
            
            foreach ($request->getDataSet()->getRows() as &$row) {
                if (array_key_exists('NRRELACIONAPARC', $row)) {
                    if ($row['NRRELACIONAPARC'] === '') {
                        $row['NRRELACIONAPARC'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'RELACIONAPARC', 1, 12, true); 
                    }
                } else {
                    $row['NRRELACIONAPARC'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'RELACIONAPARC', 1, 12, true); 
                }
                if(!array_key_exists('CDCARGO', $row)){
                    $row['CDCARGO'] = null;
                }
                if(!array_key_exists('NRPARCTESTE', $row)){
                    $row['NRPARCTESTE'] = null;
                }
                
                if($row['DTNASCIFUNDPARC'] && !empty($row['DTNASCIFUNDPARC']) && !is_null($row['DTNASCIFUNDPARC'])){
                    $this->pessoaService->setDataNascimentoPessoa($row);
                }

                if($row["__is_new"]){ 
                    $jaExistente = $this->entityManager->getRepository(Repositories::RELACIONAPARC)->findBy(
                            array("nrparcnegocio" => $row['NRPARCNEGOCIO'], "nrtiporelaciona" => $row['NRTIPORELACIONA'], "nrorg"=>$row['NRORG'])
                    );
                }else{
                    $rowAntesDeEditar= $this->entityManager->getRepository(Repositories::RELACIONAPARC)->findBy(array("nrrelacionaparc" => $row['NRRELACIONAPARC'], "nrorg"=>$row['NRORG']));
                    if((int)$rowAntesDeEditar[0]->getNrtiporelaciona() != (int)$row['NRTIPORELACIONA']){
                        $jaExistente = $this->entityManager->getRepository(Repositories::RELACIONAPARC)->findBy(
                                array("nrparcnegocio" => $row['NRPARCNEGOCIO'], "nrtiporelaciona" => $row['NRTIPORELACIONA'], "nrorg"=>$row['NRORG'])
                        );
                    }    
                }
            }
            
            if( 
                   (!is_array($jaExistente) && isset($jaExistente))
                || ($row['NRTIPORELACIONA'] == 1 &&  is_array($jaExistente) && count($jaExistente) >= 1) // não pode ter mais de uma Mãe
                || ($row['NRTIPORELACIONA'] == 2 &&  is_array($jaExistente) && count($jaExistente) >= 1) // não pode ter mais de um Pai
                || ($row['NRTIPORELACIONA'] == 100006 &&  is_array($jaExistente) && count($jaExistente) >= 1) // não pode ter mais de um Padrasto
            ){
                $response->addNotification(new DTO\Response\Notification(Messages::HCM00048_GPE_PESSOA_RELACIONAMENTO_EXISTENTE_ALERT, DTO\Response\Notification::TYPE_ALERT, 'registroExistente'));
            }else{                
                parent::save($request, $response);
                $this->pessoaService->verificaHistoricoCompetenciaPessoa($row['NRORG'], $row['NRPESSOA']);
                $this->pessoaService->atualizaHistoricoPessoa($row['NRORG'], $row['NRPESSOA']);
            }

        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteRelacionamentoParc(DTO\Request\DataSet $request, DTO\Response $response){
        $this->dataSourceName = "relacionaparc";
        parent::delete($request, $response);
    }
    
    public function getFormacaoParc(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = "gpe_formacaoparc_get";
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    
    public function getTipoFormacaoParc(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = "gpe_tipoformacaoparc_get";
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    
    public function setFormacaoParc(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $this->dataSourceName = "gpe_formacaoparc";
            foreach ($request->getDataSet()->getRows() as &$row) {
                if (array_key_exists('NRFORMACAO', $row)) {
                    if ($row['NRFORMACAO'] === '') {
                        $row['NRFORMACAO'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'DES_FORMACAO', 1, 12, true); 
                    }
                } else {
                    $row['NRFORMACAO'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'DES_FORMACAO', 1, 12, true); 
                }
                
            $row['NRESTRUTURAM'] = isset($row['NRESTRUTURAM'])?$row['NRESTRUTURAM']:null;
            $row['NRAREAFORMACAO'] = isset($row['NRAREAFORMACAO'])?$row['NRAREAFORMACAO']:null;
            $row['CDIDIOM'] = isset($row['CDIDIOM'])?$row['CDIDIOM']:null;
            $row['CDIDIOMA'] = $row['CDIDIOM'];
            $row['DSINSTITUICAO'] = isset($row['DSINSTITUICAO'])?$row['DSINSTITUICAO']:null;
            $row['NRINSTITUICAOPARC'] = isset($row['NRINSTITUICAOPARC'])?$row['NRINSTITUICAOPARC']:null;
            }
            
            parent::save($request, $response);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteFormacaoParc(DTO\Request\DataSet $request, DTO\Response $response){
        $this->dataSourceName = "gpe_formacaoparc";
        parent::delete($request, $response);
    }
    
    public function setFotoPessoa(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            foreach ($request->getDataSet()->getRows() as &$row) {
                $this->pessoaService->setFotoPessoa($row);
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function checkHistory($response, $row) {
        $condition = array(
            array(
                "columnName" => "NRORG",
                "operator" => "=",
                "value" => $this->hcmParameters->getNrorgTrabalho()
            ),
            array(
                "columnName" => strtoupper($row['saveHistoryTable']['__table_master_pk']),
                "operator" => "=",
                "value" => $row[strtoupper($row['saveHistoryTable']['__table_master_pk'])]
            ),
            array(
                "columnName" => strtoupper($row['saveHistoryTable']['__table_competenc']),
                "operator" => "=",
                "value" => $row[strtoupper($row['saveHistoryTable']['__table_competenc'])]
            )
        );
        $filterCriteria = new FilterCriteria($row['saveHistoryTable']['__table_history_name'], $condition);
        $newFilterCriteria = $this->crudService->populateParameterBag($filterCriteria, array());
        $this->crudService->find($response, $newFilterCriteria);
        

        if (count($response->getDataSets()[1]->getRows()) > 0) {
            return true;
        } else {
            return false;
        }
    }
    
    public function getRelacionadosPorVinculo(DTO\Request\Filter $request, DTO\Response $response){
        try{
            $conditions = $request->getFilterCriteria()->getConditions();
            $filters = array();
            foreach($conditions as $condition){
                $filters[$condition['columnName']] = $condition['value'];
            }
            
            Util::getValueInFilterDataSourceByName($conditions, array('P_NRORG', 'P_DTMESCOMPETENC', 'P_NRVINCULOM'), true);
            $filtro =  Util::createQueryFiltered($conditions, 'A');
            
            $relacionados = $this->pessoaService->getRelacionadosPorVinculo($filters['P_DTMESCOMPETENC'], $filters['P_NRVINCULOM'], $filters['P_NRORG'], $filtro);
            
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getRelacionadosPorVinculo', $relacionados));
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function verificarContaCorrente(DTO\Request\DataSet $request, DTO\Response $response) {
        $row = $request->getDataSet()->getRows()[0];
        $nrParcNegocio = $row['NRPARCNEGOCIO'];
        $nrOrg = $row['NRORG'];

        $retorno = $this->pessoaService->verificarContaCorrente($nrParcNegocio, $nrOrg);

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('verificarContaCorrente', $retorno));
    }
    
    protected function processConditionValue($condition) {
        return $condition['value'];
    }
    protected function populateParameterBag(FilterCriteria $filterCriteria) {

        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }
        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );
        return $newFilterCriteria;
    }
}