<?php

/**
 * User: FelipeSantos
 * Date: 20/01/22
 */

namespace HCM\Geral\Logic\Apolo;

use Doctrine\ORM\EntityManager;
use HCM\Geral\Logic\ESocialLogic;
use HCM\Geral\Services\ESocialService;
use HCM\Geral\Services\EsoSimplificadoService;
use HCM\Util\DateUtil;
use HCM\Util\HCMParameters;
use HCM\Util\Messages;
use HCM\Util\Repositories;

class InsercaoEsocialSimplificado{
    
    private $hcmParameters;
    private $jenkins;
    private $entityManager;
    private $eSocialService;
    
    public function __construct(HCMParameters $hcmParameters, ESocialService $eSocialService, EsoSimplificadoService $esoSimplificadoService){
        $this->entityManager = \Setforms2\Shared\Registry::getEntityManager();
        
        $this->hcmParameters = $hcmParameters;
        $this->eSocialService = $eSocialService;
        $this->esoSimplificadoService = $esoSimplificadoService;
        
        $this->jenkins = true;
        
        $this->envioCadastros = Repositories::ESO_ENVIOCADASTROS;
    }
    
    public function doInserts($parametros){
        
        set_time_limit(0);
        error_reporting(E_ERROR | E_PARSE);
        
        $nrorg = $this->hcmParameters->getNrorgTrabalho();
            
        foreach ($parametros as $parametro) {
            echo $parametro['NRORG'].'--'.$parametro['NRESTRUTURAM']."\n";
            $this->esocialLogic = new ESocialLogic($this->entityManager, $this->hcmParameters, $parametro['NRESTRUTURAM'], $parametro['NRTPAMBIENTE'], true);
            $eventos = $this->entityManager->getRepository(Repositories::ESO_EVENTO)->getEventosESocial($parametro['DSVERSAO']);
            foreach ($eventos as $evento) {
                $row = array_merge($evento, $parametro);
                if ($evento['IDGRUPO'] == 'I' || $evento['IDGRUPO'] == 'T') {
                    $this->setEsocadastro($row);
                }
                if ($evento['IDGRUPO'] == 'N') {
                    $this->setEsonaoperiodico($row);
                }
                if ($evento['IDGRUPO'] == 'P') {
                    $this->setEsoperiodico($row);
                }
            }
        }
    }
    
    public function setEsocadastro($row) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            $row['NRORG'] = $this->hcmParameters->getNrorgTrabalho();
            
            $row['IDATIVO'] = isset($row['IDATIVO']) ? $row['IDATIVO'] : 'S';
            $row['IDSTATUS'] = isset($row['IDSTATUS']) ? $row['IDSTATUS'] : 'P';
            $row['IDEVENTO'] = isset($row['IDEVENTO']) ? $row['IDEVENTO'] : null;
            $row['DTENVIO'] = isset($row['DTENVIO']) ? $row['DTENVIO'] : null;
            $row['DTRESPOSTA'] = isset($row['DTRESPOSTA']) ? $row['DTRESPOSTA'] : null;
            $row['DTPROCESSAMENTO'] = isset($row['DTPROCESSAMENTO']) ? $row['DTPROCESSAMENTO'] : null;
            $row['NRPROTOCOLO'] = isset($row['NRPROTOCOLO']) ? $row['NRPROTOCOLO'] : null;
            $row['NRRECIBO'] = isset($row['NRRECIBO']) ? $row['NRRECIBO'] : null;
            $row['CDERRO'] = isset($row['CDERRO']) ? $row['CDERRO'] : null;
            $row['DSDIRXMLENV'] = isset($row['DSDIRXMLENV']) ? $row['DSDIRXMLENV'] : null;
            $row['DSDIRXMLRETENV'] = isset($row['DSDIRXMLRETENV']) ? $row['DSDIRXMLRETENV'] : null;
            $row['DSDIRXMLRETPRO'] = isset($row['DSDIRXMLRETPRO']) ? $row['DSDIRXMLRETPRO'] : null;
            $row['DSOBSERVACAO'] = isset($row['DSOBSERVACAO']) ? $row['DSOBSERVACAO'] : null;
            $row['DSOBSERVACAO2'] = isset($row['DSOBSERVACAO2']) ? $row['DSOBSERVACAO2'] : null;
            
            if($row['NMEVPRECED']){
                $eventosPreced = explode(',', $row['NMEVPRECED']);
                foreach($eventosPreced as $eventoPreced){
                    $arrItens = $this->esoSimplificadoService->getItensParaEnvioEvento($eventoPreced, $row['IDGRUPO'], $row);
                    if ($arrItens) {
                        return;
                    }
                }
            }
            
            //verifica dependencia
            if($row['NMEVDEPEND']){
                $eventosDepend = explode(',', $row['NMEVDEPEND']);
                 foreach($eventosDepend as $eventoDepend){
                    $arrItens = $this->esoSimplificadoService->getItensParaEnvioEvento($eventoDepend, $row['IDGRUPO'], $row);
                    if (!$arrItens) {
                        return;
                    }
                }
            }
            
            echo '>>>Iniciando setEsocadastro [Org:' . $row['NRORG'] . '/Estrutura:' . $row['NRESTRUTURAM'] . '/Evento' . $row['NMEVENTO'] . ']<<<' . PHP_EOL;

            $campoChave = $this->camposChave[$row['NMEVENTO']];
            if ($row['NMEVENTO'] == 'S-1000') {
                $row['NRCHAVE'] = [$row[$campoChave]];
            } else {
                $row['NRCHAVE'] = empty($row[$campoChave]) ? [null] : $row[$campoChave];
                
            }
            foreach ($row['NRCHAVE'] as $nrchave) {
                $row[$campoChave] = $nrchave;
                
                $arrItens = $this->esoSimplificadoService->getItensParaEnvioEvento($row['NMEVENTO'], $row['IDGRUPO'], $row);
                if (empty($arrItens)) {
                    echo Messages::HCM09000_ESO_ENVIOS_NOT_FOUND_ERROR . PHP_EOL;
                    break;
                }
                
                try {
                    $this->entityManager->beginTransaction();
                    
                    foreach($arrItens as $item) {
                        $row['NRCHAVE'] = $item['NRCHAVE'];
                        $row['NRTABELA'] = isset($item['NRTABELA']) ? $item['NRTABELA'] : '';
                        $row['IDOPERACAO'] = isset($item['IDOPERACAO']) ? $item['IDOPERACAO'] : 'I';
                        $row['DTMESCOMPETENC'] = $item['DTMESCOMPETENC'];
            
                        try {
                            $this->esoSimplificadoService->beforeInsertCadastro(
                                $row['NRORG'], $row['NRTPAMBIENTE'], $row['NRESTRUTURAM'], $row['CDCNPJEMPREGADOR'], $row['DTMESCOMPETENC'], $row['NMEVENTO'], $row['NRCHAVE'], $row['NRTABELA'], $row['IDOPERACAO']
                            );
                        } catch(\Exception $e) {
                            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE) {
                                if($e->getMessage() == Messages::HCM09000_ESO_UNIQUE_ENVIO_ERROR){
                                    echo Messages::HCM09000_ESO_UNIQUE_ENVIO_ERROR . PHP_EOL;
                                } else {
                                    echo $e->getMessage() . PHP_EOL;
                                }
                                continue;
                            } else {
                                throw $e;
                            }
                        }
                        
                        $this->esocialLogic->novoEsoCadastro(
                            $row['NRESTRUTURAM'], $row['NMEVENTO'], $row['DSVERSAO'], $row['NRTPAMBIENTE'], $row['NRCHAVE'], $row['DTMESCOMPETENC'], $row['IDOPERACAO']
                        );
                    }
                    
                    $this->entityManager->flush();
                    $this->entityManager->commit();
                } catch(\Exception $e) {
                    $this->entityManager->rollback();
                    echo $e->getMessage() . PHP_EOL;
                }
            }

            echo '>>><<<' . PHP_EOL;
        } catch(\Exception $e) {
            echo 'Erro setEsocadastro: ' . $e->getMessage() . PHP_EOL;
            echo '>>><<<' . PHP_EOL;
        }
    }
    
    public function setEsonaoperiodico($row) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            $row['NRORG'] = $this->hcmParameters->getNrorgTrabalho();
            
            $row['IDATIVO'] = isset($row['IDATIVO']) ? $row['IDATIVO'] : 'S';
            $row['IDSTATUS'] = isset($row['IDSTATUS']) ? $row['IDSTATUS'] : 'P';
            $row['IDEVENTO'] = isset($row['IDEVENTO']) ? $row['IDEVENTO'] : null;
            $row['DTENVIO'] = isset($row['DTENVIO']) ? $row['DTENVIO'] : null;
            $row['DTRESPOSTA'] = isset($row['DTRESPOSTA']) ? $row['DTRESPOSTA'] : null;
            $row['DTPROCESSAMENTO'] = isset($row['DTPROCESSAMENTO']) ? $row['DTPROCESSAMENTO'] : null;
            $row['NRPROTOCOLO'] = isset($row['NRPROTOCOLO']) ? $row['NRPROTOCOLO'] : null;
            $row['NRRECIBO'] = isset($row['NRRECIBO']) ? $row['NRRECIBO'] : null;
            $row['CDERRO'] = isset($row['CDERRO']) ? $row['CDERRO'] : null;
            $row['DSDIRXMLENV'] = isset($row['DSDIRXMLENV']) ? $row['DSDIRXMLENV'] : null;
            $row['DSDIRXMLRETENV'] = isset($row['DSDIRXMLRETENV']) ? $row['DSDIRXMLRETENV'] : null;
            $row['DSDIRXMLRETPRO'] = isset($row['DSDIRXMLRETPRO']) ? $row['DSDIRXMLRETPRO'] : null;
            $row['DSDIRXMLRETTOT'] = isset($row['DSDIRXMLRETTOT']) ? $row['DSDIRXMLRETTOT'] : null;
            $row['DSOBSERVACAO'] = isset($row['DSOBSERVACAO']) ? $row['DSOBSERVACAO'] : null;
            $row['DSOBSERVACAO2'] = isset($row['DSOBSERVACAO2']) ? $row['DSOBSERVACAO2'] : null;
            $row['NRENVIOEXCL'] = isset($row['NRENVIOEXCL']) ? $row['NRENVIOEXCL'] : null;
            $row['VRBASEMENSAL'] = isset($row['VRBASEMENSAL']) ? $row['VRBASEMENSAL']: null;
            $row['VRBASE13'] = isset($row['VRBASE13']) ? $row['VRBASE13']: null;
            $row['VRVALORMENSAL'] = isset($row['VRVALORMENSAL']) ? $row['VRVALORMENSAL']: null;
            $row['VRVALOR13'] = isset($row['VRVALOR13']) ? $row['VRVALOR13']: null;
            $row['VRVALORMATERMENSAL'] = isset($row['VRVALORMATERMENSAL']) ? $row['VRVALORMATERMENSAL']: null;
            $row['VRVALORMATER13'] = isset($row['VRVALORMATER13']) ? $row['VRVALORMATER13']: null;
            $row['VRSALFAMILIA'] = isset($row['VRSALFAMILIA']) ? $row['VRSALFAMILIA']: null;
            $row['VRSALFAMILIA13'] = isset($row['VRSALFAMILIA13']) ? $row['VRSALFAMILIA13']: null;
            $row['VRCALCULADO'] = isset($row['VRCALCULADO']) ? $row['VRCALCULADO']: null;
            $row['VRDESCONTADO'] = isset($row['VRDESCONTADO']) ? $row['VRDESCONTADO']: null;
            $row['NRESTRUTLOTACAO'] = isset($row['NRESTRUTLOTACAO']) ? $row['NRESTRUTLOTACAO']: null;

            $row['NRVINCULOM'] = empty($row['NRVINCULOM']) ? [null] : $row['NRVINCULOM'];
            
            if($row['NMEVPRECED']){
                $eventosPreced = explode(',', $row['NMEVPRECED']);
                foreach($eventosPreced as $eventoPreced){
                    $arrItens = $this->esoSimplificadoService->getItensParaEnvioEvento($eventoPreced, $row['IDGRUPO'], $row);
                    if ($arrItens) {
                        return;
                    }
                }
            }
            
            //verifica dependencia
            if($row['NMEVDEPEND']){
                $eventosDepend = explode(',', $row['NMEVDEPEND']);
                 foreach($eventosDepend as $eventoDepend){
                    $arrItens = $this->esoSimplificadoService->getItensParaEnvioEvento($eventoDepend, $row['IDGRUPO'], $row);
                    if (!$arrItens) {
                        return;
                    }
                }
            }
            
            echo '>>>Iniciando setEsonaoperiodico [Org:' . $row['NRORG'] . '/Estrutura:' . $row['NRESTRUTURAM'] . '/Evento' . $row['NMEVENTO'] . ']<<<' . PHP_EOL;

            foreach ($row['NRVINCULOM'] as $index => $nrvinculom) {
                $row['NRVINCULOM'] = $nrvinculom;
                $row['NMVINCULOM'] = empty($row['NMVINCULOM_LIST']) ? null : $row['NMVINCULOM_LIST'][$index];
                $row['NRPESSOA'] = empty($row['NRPESSOA_LIST']) ? null : $row['NRPESSOA_LIST'][$index];
                $row['DTADMISSAOVINC'] = empty($row['DTADMISSAOVINC_LIST']) ? null : $row['DTADMISSAOVINC_LIST'][$index];
                $row['DTRESCISAOVINC'] = empty($row['DTRESCISAOVINC_LIST']) ? null : $row['DTRESCISAOVINC_LIST'][$index];
            
                $arrItens = $this->esoSimplificadoService->getItensParaEnvioEvento($row['NMEVENTO'], $row['IDGRUPO'], $row);
                if (empty($arrItens)) {
                    echo Messages::HCM09000_ESO_ENVIOS_NOT_FOUND_ERROR . PHP_EOL;
                    break;
                }

                foreach($arrItens as $item) {
                    $row['NRCHAVE'] = $item['NRCHAVE'];
                    $row['NRTABELA'] = isset($item['NRTABELA']) ? $item['NRTABELA'] : '';
                    $row['IDOPERACAO'] = isset($item['IDOPERACAO']) ? $item['IDOPERACAO'] : 'I';
                    $row['DTMESCOMPETENC'] = $item['DTMESCOMPETENC'];
                    $row['NRVINCULOM'] = $item['NRVINCULOM'];
        
                    try {
                        $this->esoSimplificadoService->beforeInsertNaoPeriodico(
                            $row['NRORG'], $row['NRTPAMBIENTE'], $row['NRESTRUTURAM'], $row['CDCNPJEMPREGADOR'], $row['NRVINCULOM'], $row['DTMESCOMPETENC'], $row['NMEVENTO'], $row['NRCHAVE'], $row['NRTABELA'], $row['IDOPERACAO']
                        );
                    } catch(\Exception $e) {
                        if ($e->getCode() == Messages::ALERT_MESSAGE_CODE) {
                            if($e->getMessage() == Messages::HCM09000_ESO_UNIQUE_ENVIO_ERROR){
                                echo Messages::HCM09000_ESO_UNIQUE_ENVIO_ERROR . PHP_EOL;
                            } else {
                                echo $e->getMessage() . PHP_EOL;
                            }
                            continue;
                        } else {
                            throw $e;
                        }
                    }
                    
                    $this->esocialLogic->novoEsoNaoPeriodico(
                        $row['NRESTRUTURAM'], $row['NRVINCULOM'], $row['NMEVENTO'], $row['DSVERSAO'], $row['NRTPAMBIENTE'], $row['NRCHAVE'], $row['DTMESCOMPETENC'], $row['IDOPERACAO'], $row['NRTABELA']
                    );
                }
            }

            $this->entityManager->flush();

            echo '>>><<<' . PHP_EOL;
        } catch(\Exception $e) {
            echo 'Erro setEsonaoperiodico: ' . $e->getMessage() . PHP_EOL;
            echo '>>><<<' . PHP_EOL;
        }
    }
    
    public function setEsoperiodico($row) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            $row['NRORG'] = $this->hcmParameters->getNrorgTrabalho();
            
            $row['IDATIVO'] = isset($row['IDATIVO']) ? $row['IDATIVO'] : 'S';
            $row['IDSTATUS'] = isset($row['IDSTATUS']) ? $row['IDSTATUS'] : 'P';
            $row['IDEVENTO'] = isset($row['IDEVENTO']) ? $row['IDEVENTO'] : null;
            $row['DTENVIO'] = isset($row['DTENVIO']) ? $row['DTENVIO'] : null;
            $row['DTRESPOSTA'] = isset($row['DTRESPOSTA']) ? $row['DTRESPOSTA'] : null;
            $row['DTPROCESSAMENTO'] = isset($row['DTPROCESSAMENTO']) ? $row['DTPROCESSAMENTO'] : null;
            $row['NRPROTOCOLO'] = isset($row['NRPROTOCOLO']) ? $row['NRPROTOCOLO'] : null;
            $row['NRRECIBO'] = isset($row['NRRECIBO']) ? $row['NRRECIBO'] : null;
            $row['CDERRO'] = isset($row['CDERRO']) ? $row['CDERRO'] : null;
            $row['DSDIRXMLENV'] = isset($row['DSDIRXMLENV']) ? $row['DSDIRXMLENV'] : null;
            $row['DSDIRXMLRETENV'] = isset($row['DSDIRXMLRETENV']) ? $row['DSDIRXMLRETENV'] : null;
            $row['DSDIRXMLRETPRO'] = isset($row['DSDIRXMLRETPRO']) ? $row['DSDIRXMLRETPRO'] : null;
            $row['DSOBSERVACAO'] = isset($row['DSOBSERVACAO']) ? $row['DSOBSERVACAO'] : null;
            $row['DSOBSERVACAO2'] = isset($row['DSOBSERVACAO2']) ? $row['DSOBSERVACAO2'] : null;
            
            if($row['NMEVPRECED']){
                $eventosPreced = explode(',', $row['NMEVPRECED']);
                foreach($eventosPreced as $eventoPreced){
                    $arrItens = $this->esoSimplificadoService->getItensParaEnvioEvento($eventoPreced, $row['IDGRUPO'], $row);
                    if ($arrItens) {
                        return;
                    }
                }
            }
            
            //verifica dependencia
            if($row['NMEVDEPEND']){
                $eventosDepend = explode(',', $row['NMEVDEPEND']);
                 foreach($eventosDepend as $eventoDepend){
                    $arrItens = $this->esoSimplificadoService->getItensParaEnvioEvento($eventoDepend, $row['IDGRUPO'], $row);
                    if (!$arrItens) {
                        return;
                    }
                }
            }
            
            echo '>>>Iniciando setEsoperiodico [Org:' . $row['NRORG'] . '/Estrutura:' . $row['NRESTRUTURAM'] . '/Evento' . $row['NMEVENTO'] . ']<<<' . PHP_EOL;

            $campoChave = $this->camposChave[$row['NMEVENTO']];
            if ($row['NMEVENTO'] == 'S-1000') {
                $row['NRCHAVE'] = [$row[$campoChave]];
            } else {
                $row['NRCHAVE'] = empty($row[$campoChave]) ? [null] : $row[$campoChave];
                
            }
            foreach ($row['NRCHAVE'] as $nrchave) {
                $row[$campoChave] = $nrchave;
                
                $arrItens = $this->esoSimplificadoService->getItensParaEnvioEvento($row['NMEVENTO'], $row['IDGRUPO'], $row);
                if (empty($arrItens)) {
                    echo Messages::HCM09000_ESO_ENVIOS_NOT_FOUND_ERROR . PHP_EOL;
                    break;
                }
                
                foreach($arrItens as $item) {
                    $row['NRCHAVE'] = $item['NRCHAVE'];
                    $row['NRTABELA'] = isset($item['NRTABELA']) ? $item['NRTABELA'] : '';
                    $row['IDOPERACAO'] = isset($item['IDOPERACAO']) ? $item['IDOPERACAO'] : 'I';
                    $row['DTMESCOMPETENC'] = $item['DTMESCOMPETENC'];
        
                    try {
                        $this->esoSimplificadoService->beforeInsertCadastro(
                            $row['NRORG'], $row['NRTPAMBIENTE'], $row['NRESTRUTURAM'], $row['CDCNPJEMPREGADOR'], $row['DTMESCOMPETENC'], $row['NMEVENTO'], $row['NRCHAVE'], $row['NRTABELA'], $row['IDOPERACAO']
                        );
                    } catch(\Exception $e) {
                        if ($e->getCode() == Messages::ALERT_MESSAGE_CODE) {
                            if($e->getMessage() == Messages::HCM09000_ESO_UNIQUE_ENVIO_ERROR){
                                echo Messages::HCM09000_ESO_UNIQUE_ENVIO_ERROR . PHP_EOL;
                            } else {
                                echo $e->getMessage() . PHP_EOL;
                            }
                            continue;
                        } else {
                            throw $e;
                        }
                    }
                    
                    $this->esocialLogic->novoEsoCadastro(
                        $row['NRESTRUTURAM'], $row['NMEVENTO'], $row['DSVERSAO'], $row['NRTPAMBIENTE'], $row['NRCHAVE'], $row['DTMESCOMPETENC'], $row['IDOPERACAO']
                    );
                }
            }

            echo '>>><<<' . PHP_EOL;
        } catch(\Exception $e) {
            echo 'Erro setEsoperiodico: ' . $e->getMessage() . PHP_EOL;
            echo '>>><<<' . PHP_EOL;
        }
    }
}