<?php
namespace HCM\Geral\Services;

use Doctrine\ORM\EntityManager;
use HCM\Geral\Entity\GpevinculomEntity;
use HCM\Util\DateUtil;
use HCM\Util\FPA;
use HCM\Util\TkDI;
use HCM\Util\HCMParameters;
use HCM\Util\Messages;
use HCM\Util\MsgProcesso;
use HCM\Util\Repositories;
use HCM\Util\Util;
use Zeedhi\Framework\HTTP\Kernel;
use HCM\Geral\Services\FileService;
use HCM\Geral\Services\UploadFileService;
use HCM\Geral\Logic\ImportacaoXmlEsocialLogic;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\Remote\FileUploader\Server;
use Symfony\Component\DependencyInjection\SimpleXMLElement;

class ImportacaoXmlEsocialService {
    
    public function __construct(EntityManager $entityManager, HCMParameters $hcmParameters, Kernel $httpKernel)
    {
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
        $this->httpKernel = $httpKernel;
        $this->importacaoXmlEsocialLogic = new ImportacaoXmlEsocialLogic($entityManager, $hcmParameters);
    }
    
    public function importarXml($row)
    {
        try{
            $nrorg = $this->hcmParameters->getNrorgTrabalho();
            $nrOrgPadrao = $this->hcmParameters->getNrorgPadrao();
            $mesCompetencia = $this->hcmParameters->getDtCompetencia();
            $this->dtmescompetenc = $mesCompetencia;
            $row['NRINSCRICAO'] = !empty($row['NRINSCRICAO']) ? str_replace(['.', '-', '/', ','], ['','','',''], $row['NRINSCRICAO']) : '';
            $mensagens = array();
            $mensagem = array();
            $arquivo = $row['DSPATH'][0];
            foreach ($row['DSPATH'] as $arquivo) {
                $file = $this->httpKernel->factoryFromFileData($arquivo, FPA::getTempDirectory()."/");
                
                if (!$file->isFile()) {
                    throw new \Exception("Falha ao gravar o arquivo.");
                }
                
                $file = file_get_contents($file->getPathname());
                $xml = new SimpleXMLElement($file);
                
                if (isset($xml->loteEventos)) {
                    $mensagensLote = $this->importarXmlLote($row, $xml);
                    foreach ($mensagensLote as $evento => $mensagem) {
                        $mensagens[$arquivo['name'] . ' - Evento ' . $evento++] = $mensagem;
                    }
                } else {
                    $mensagens[$arquivo['name']] = $this->importarXmlEvento($row, $xml);
                }
            }
            
            return $mensagens;
        }catch (\Exception $e) {            
            throw $e;
        }
        
    }
    
    public function importarXmlLote($row, $xml)
    {
        $mensagensLote = array();
        
        foreach ($xml->loteEventos->eSocial->envioLoteEventos->eventos->evento as $evento) {
            $mensagensLote[] = $this->importarXmlEvento($row, $evento->eSocial);
        }
        
        return $mensagensLote;
    }
    
    public function importarXmlEvento($row, $xml)
    {
        $xmlns = explode('/', $xml->getNamespaces()[""]);
                
        if($xmlns[count($xmlns)-1] != 'v02_05_00'){
            $mensagem = ['status'  => false,
                          'message' => 'O arquivo a ser importatado deve ser da versão 2.5.00 do ESocial.'];
            return $mensagem;
        }
        
        $paramOrg = $this->entityManager->getRepository(Repositories::GPE_PARAMORG)->findOneBy(array('nrorg' => $this->hcmParameters->getNrorgTrabalho()));
        
        if(!$paramOrg){
            $mensagem = ['status'  => false,
                          'message' => 'Não existe parâmetro de organização cadastrado.'];
            return $mensagem;
        }
        
        try {
            switch($row['NMEVENTO']){
                case 'S-1000':
                    $mensagem =  $this->importacaoXmlEsocialLogic->insertXmlS1000($xml, $row['NRINSCRICAO'], $row['IDOPTSIMPLES']);
                    break;
                case 'S-1005':
                    $mensagem =  $this->importacaoXmlEsocialLogic->insertXmlS1005($xml, $row['IDOPTSIMPLES']);
                    break;
                case 'S-1020':
                    $mensagem =  $this->importacaoXmlEsocialLogic->insertXmlS1020($xml, $row['NRINSCRICAO'], $row['IDOPTSIMPLES']);
                    break;
                case 'S-1030':
                    $mensagem =  $this->importacaoXmlEsocialLogic->insertXmlS1030($xml);
                    break;
                case 'S-1040':
                    $mensagem =  $this->importacaoXmlEsocialLogic->insertXmlS1040($xml);
                    break;
                case 'S-1050':
                    $mensagem =  $this->importacaoXmlEsocialLogic->insertXmlS1050($xml);
                    break;
                case 'S-2200':
                    $mensagem =  $this->importacaoXmlEsocialLogic->insertXmlS2200($xml); 
                    break;
                case 'S-2205':
                    $mensagem =  $this->importacaoXmlEsocialLogic->insertXmlS2205($xml); 
                    break;
                case 'S-2206':
                    $mensagem =  $this->importacaoXmlEsocialLogic->insertXmlS2206($xml); 
                    break;
                case 'S-2230':
                    $mensagem =  $this->importacaoXmlEsocialLogic->insertXmlS2230($xml); 
                    break;
                case 'S-2300':
                    $mensagem =  $this->importacaoXmlEsocialLogic->insertXmlS2300($xml, $row['NRTIPOVINCULOM']);
                    break;
                case 'S-2306':
                    $mensagem =  $this->importacaoXmlEsocialLogic->insertXmlS2306($xml);
                    break;
                default:
                    $mensagem = ['status'  => false,
                                 'message' => 'Evento informado não identificado.'];
            }
        }catch (\Exception $e) {            
            $mensagem = ['status'  => false,
                         'message' => $e->getMessage()];
        }
        
        return $mensagem;
    }
    
}
